/*
 * Copyright (c) Members of the EGEE Collaboration. 2010.
 * See http://www.eu-egee.org/partners/ for details on the copyright holders.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * Authors: Zsolt Molnar (Zsolt.Molnar@cern.ch)
 */

#include "gfal_is_ifce_unittest.h"


START_TEST (gfal_is_ifce_test_strtok_uri)
{
    /* Check one URI - no port */
    char* uri = "ldap.foo.bar";
    char* uri_expected = "ldap://ldap.foo.bar";
    char* uri_res = gfal_is_interafce_test_strtok_uri(uri);
    fail_if(strcmp(uri_res, uri_expected) != 0);

    /* Check one uri with port */
    /* OK, normally, I should free the variables, however, it is "only" a unit test. 
       I do not care. */
    uri = "ldap.foo.bar:8080";
    uri_expected = "ldap://ldap.foo.bar:8080";
    uri_res = gfal_is_interafce_test_strtok_uri(uri);
    fail_if(strcmp(uri_res, uri_expected) != 0);

    /* Check two URI-s, no port */
    uri = "ldap.foo.bar,ldap2.foo.bar";
    uri_expected = "ldap://ldap.foo.bar,ldap://ldap2.foo.bar";
    uri_res = gfal_is_interafce_test_strtok_uri(uri);
    fail_if(strcmp(uri_res, uri_expected) != 0);

    /* Check two URI-s, with port */
    uri = "ldap.foo.bar:8080,ldap2.foo.bar:8080";
    uri_expected = "ldap://ldap.foo.bar:8080,ldap://ldap2.foo.bar:8080";
    uri_res = gfal_is_interafce_test_strtok_uri(uri);
    fail_if(strcmp(uri_res, uri_expected) != 0);

    /* Check empty string. Should return empty string */
    uri = "";
    uri_expected = "";
    uri_res = gfal_is_interafce_test_strtok_uri(uri);
    fail_if(strcmp(uri_res, uri_expected) != 0);
    
    /* Check NULL. Should return NULL */
    uri = NULL;
    uri_expected = NULL;
    uri_res = gfal_is_interafce_test_strtok_uri(uri);
    fail_if(uri_res != NULL);

    /* Check comma, should return - well, a meaningless stuff */
    uri = ",";
    uri_expected = "ldap://,ldap://";
    uri_res = gfal_is_interafce_test_strtok_uri(uri);
    fail_if(strcmp(uri_res, uri_expected) != 0);
}
END_TEST

Suite* gfal_is_ifce_unittest_suite (void)
{
    Suite *s = suite_create ("GFAL is-interface unit test suite");
    
    TCase *tc_case_1 = tcase_create ("is-interface unit tests");
    tcase_add_test (tc_case_1, gfal_is_ifce_test_strtok_uri);
    suite_add_tcase (s, tc_case_1);

    return s;
}

int main(void)
{
	int number_failed;

	Suite *s = gfal_is_ifce_unittest_suite();
	SRunner *sr = srunner_create (s);
    	srunner_set_fork_status (sr, CK_NOFORK); /* for easier debug */
	srunner_run_all (sr, CK_VERBOSE);
	number_failed = srunner_ntests_failed (sr);
	srunner_free (sr);

	return (number_failed == 0) ? EXIT_SUCCESS : EXIT_FAILURE;
}
