#! /bin/bash
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# Execute the unit tests
# Author:Todor Manev CERN IT-GT

SCRIPT=$(readlink -f $0)
SCRIPTPATH=`dirname $SCRIPT`
BUILD_DIR=$SCRIPTPATH/../../build  #script is in /test/unit

sudo updatedb
ccheck_path=`locate libcheck.so.0 | head -1 | sed 's/libcheck.so.0//'`
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$ccheck_path:/opt/c-check/lib
echo $ccheck_path
echo $LD_LIBRARY_PATH

EXECUTABLE=./gfal_is_ifce_unittest
VALGRIND_CMD="valgrind -v --tool=memcheck --error-limit=no  --trace-children=yes --leak-check=yes --undef-value-errors=yes --num-callers=20 --leak-resolution=high --show-reachable=yes"

function execute_tests
{
	pushd $BUILD_DIR/src &> /dev/null
	echo
	echo "**********************************"
	echo "Executing unit tests"
	echo "**********************************"
	echo
	$EXECUTABLE
	res=$?
}

function execute_tests_with_valgrind
{
	pushd $BUILD_DIR/src/.libs &> /dev/null
	echo
	echo "**********************************"
	echo "Executing unit tests with valgrind"
	echo "**********************************"
	echo
	$VALGRIND_CMD $EXECUTABLE 2>&1
}
	
execute_tests
#execute_tests_with_valgrind
popd &> /dev/null
exit $res

